=== modified file 'NEWS'
--- NEWS	2010-05-11 08:36:16 +0000
+++ NEWS	2010-05-06 23:49:39 +0000
@@ -17,8 +17,6 @@
   ``Repository`` objects; they now return ``branch.BranchWriteLockResult``
   and ``repository.RepositoryWriteLockResult`` objects. This makes
   changing the API in future easier and permits some cleaner calling code.
-  The lock_read method has also changed from having no defined return
-  value to returning ``LogicalLockResult`` objects.
   (Robert Collins)
 
 New Features

=== modified file 'bzrlib/branch.py'
--- bzrlib/branch.py	2010-05-11 08:36:16 +0000
+++ bzrlib/branch.py	2010-05-06 23:54:05 +0000
@@ -49,7 +49,7 @@
 from bzrlib.decorators import needs_read_lock, needs_write_lock, only_raises
 from bzrlib.hooks import HookPoint, Hooks
 from bzrlib.inter import InterObject
-from bzrlib.lock import _RelockDebugMixin, LogicalLockResult
+from bzrlib.lock import _RelockDebugMixin
 from bzrlib import registry
 from bzrlib.symbol_versioning import (
     deprecated_in,
@@ -295,7 +295,8 @@
     def lock_read(self):
         """Lock the branch for read operations.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         raise NotImplementedError(self.lock_read)
 
@@ -2275,7 +2276,7 @@
     _legacy_formats[0].network_name(), _legacy_formats[0].__class__)
 
 
-class BranchWriteLockResult(LogicalLockResult):
+class BranchWriteLockResult(object):
     """The result of write locking a branch.
 
     :ivar branch_token: The token obtained from the underlying branch lock, or
@@ -2284,10 +2285,10 @@
     """
 
     def __init__(self, unlock, branch_token):
-        LogicalLockResult.__init__(self, unlock)
         self.branch_token = branch_token
+        self.unlock = unlock
 
-    def __repr__(self):
+    def __str__(self):
         return "BranchWriteLockResult(%s, %s)" % (self.branch_token,
             self.unlock)
 
@@ -2378,7 +2379,8 @@
     def lock_read(self):
         """Lock the branch for read operations.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         if not self.is_locked():
             self._note_lock('r')
@@ -2392,7 +2394,7 @@
             took_lock = False
         try:
             self.control_files.lock_read()
-            return LogicalLockResult(self.unlock)
+            return self
         except:
             if took_lock:
                 self.repository.unlock()

=== modified file 'bzrlib/lock.py'
--- bzrlib/lock.py	2010-05-11 08:36:16 +0000
+++ bzrlib/lock.py	2010-04-16 07:56:51 +0000
@@ -88,20 +88,6 @@
                              self.lock_url, self.details)
 
 
-class LogicalLockResult(object):
-    """The result of a lock_read/lock_write/lock_tree_write call on lockables.
-
-    :ivar unlock: A callable which will unlock the lock.
-    """
-
-    def __init__(self, unlock):
-        self.unlock = unlock
-
-    def __repr__(self):
-        return "LogicalLockResult(%s)" % (self.unlock)
-
-
-
 def cant_unlock_not_held(locked_object):
     """An attempt to unlock failed because the object was not locked.
 

=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2010-05-11 08:36:16 +0000
+++ bzrlib/remote.py	2010-05-06 23:41:35 +0000
@@ -1000,7 +1000,8 @@
     def lock_read(self):
         """Lock the repository for read operations.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         # wrong eventually - want a local lock cache context
         if not self._lock_mode:
@@ -1014,7 +1015,7 @@
                 repo.lock_read()
         else:
             self._lock_count += 1
-        return lock.LogicalLockResult(self.unlock)
+        return self
 
     def _remote_lock_write(self, token):
         path = self.bzrdir._path_for_remote_call(self._client)
@@ -2395,7 +2396,8 @@
     def lock_read(self):
         """Lock the branch for read operations.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         self.repository.lock_read()
         if not self._lock_mode:
@@ -2406,7 +2408,7 @@
                 self._real_branch.lock_read()
         else:
             self._lock_count += 1
-        return lock.LogicalLockResult(self.unlock)
+        return self
 
     def _remote_lock_write(self, token):
         if token is None:

=== modified file 'bzrlib/repofmt/pack_repo.py'
--- bzrlib/repofmt/pack_repo.py	2010-05-11 08:36:16 +0000
+++ bzrlib/repofmt/pack_repo.py	2010-05-06 23:41:35 +0000
@@ -64,7 +64,6 @@
     GraphIndex,
     InMemoryGraphIndex,
     )
-from bzrlib.lock import LogicalLockResult
 from bzrlib.repofmt.knitrepo import KnitRepository
 from bzrlib.repository import (
     CommitBuilder,
@@ -2342,10 +2341,6 @@
         return self._write_lock_count
 
     def lock_write(self, token=None):
-        """Lock the repository for writes.
-
-        :return: A bzrlib.repository.RepositoryWriteLockResult.
-        """
         locked = self.is_locked()
         if not self._write_lock_count and locked:
             raise errors.ReadOnlyError(self)
@@ -2363,10 +2358,6 @@
         return RepositoryWriteLockResult(self.unlock, None)
 
     def lock_read(self):
-        """Lock the repository for reads.
-
-        :return: A bzrlib.lock.LogicalLockResult.
-        """
         locked = self.is_locked()
         if self._write_lock_count:
             self._write_lock_count += 1
@@ -2379,7 +2370,7 @@
             for repo in self._fallback_repositories:
                 repo.lock_read()
             self._refresh_data()
-        return LogicalLockResult(self.unlock)
+        return self
 
     def leave_lock_in_place(self):
         # not supported - raise an error

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2010-05-11 08:36:16 +0000
+++ bzrlib/repository.py	2010-05-06 23:54:05 +0000
@@ -61,7 +61,7 @@
     ROOT_ID,
     entry_factory,
     )
-from bzrlib.lock import _RelockDebugMixin, LogicalLockResult
+from bzrlib.lock import _RelockDebugMixin
 from bzrlib import registry
 from bzrlib.trace import (
     log_exception_quietly, note, mutter, mutter_callsite, warning)
@@ -860,7 +860,7 @@
         # versioned roots do not change unless the tree found a change.
 
 
-class RepositoryWriteLockResult(LogicalLockResult):
+class RepositoryWriteLockResult(object):
     """The result of write locking a repository.
 
     :ivar repository_token: The token obtained from the underlying lock, or
@@ -869,10 +869,10 @@
     """
 
     def __init__(self, unlock, repository_token):
-        LogicalLockResult.__init__(self, unlock)
         self.repository_token = repository_token
+        self.unlock = unlock
 
-    def __repr__(self):
+    def __str__(self):
         return "RepositoryWriteLockResult(%s, %s)" % (self.repository_token,
             self.unlock)
 
@@ -1434,7 +1434,7 @@
             for repo in self._fallback_repositories:
                 repo.lock_read()
             self._refresh_data()
-        return LogicalLockResult(self.unlock)
+        return self
 
     def get_physical_lock_status(self):
         return self.control_files.get_physical_lock_status()

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2010-05-11 08:36:16 +0000
+++ bzrlib/tree.py	2010-04-30 11:03:59 +0000
@@ -582,10 +582,6 @@
             yield child.file_id
 
     def lock_read(self):
-        """Lock this tree for multiple read only operations.
-        
-        :return: A bzrlib.lock.LogicalLockResult.
-        """
         pass
 
     def revision_tree(self, revision_id):

=== modified file 'bzrlib/workingtree.py'
--- bzrlib/workingtree.py	2010-05-11 08:36:16 +0000
+++ bzrlib/workingtree.py	2010-05-06 23:41:35 +0000
@@ -77,7 +77,6 @@
 
 from bzrlib import symbol_versioning
 from bzrlib.decorators import needs_read_lock, needs_write_lock
-from bzrlib.lock import LogicalLockResult
 from bzrlib.lockable_files import LockableFiles
 from bzrlib.lockdir import LockDir
 import bzrlib.mutabletree
@@ -1803,14 +1802,15 @@
 
         This also locks the branch, and can be unlocked via self.unlock().
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         if not self.is_locked():
             self._reset_data()
         self.branch.lock_read()
         try:
             self._control_files.lock_read()
-            return LogicalLockResult(self.unlock)
+            return self
         except:
             self.branch.unlock()
             raise
@@ -1818,14 +1818,15 @@
     def lock_tree_write(self):
         """See MutableTree.lock_tree_write, and WorkingTree.unlock.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         if not self.is_locked():
             self._reset_data()
         self.branch.lock_read()
         try:
             self._control_files.lock_write()
-            return LogicalLockResult(self.unlock)
+            return self
         except:
             self.branch.unlock()
             raise
@@ -1833,14 +1834,15 @@
     def lock_write(self):
         """See MutableTree.lock_write, and WorkingTree.unlock.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         if not self.is_locked():
             self._reset_data()
         self.branch.lock_write()
         try:
             self._control_files.lock_write()
-            return LogicalLockResult(self.unlock)
+            return self
         except:
             self.branch.unlock()
             raise

=== modified file 'bzrlib/workingtree_4.py'
--- bzrlib/workingtree_4.py	2010-05-11 08:36:16 +0000
+++ bzrlib/workingtree_4.py	2010-05-06 23:41:35 +0000
@@ -53,7 +53,6 @@
 from bzrlib.decorators import needs_read_lock, needs_write_lock
 from bzrlib.filters import filtered_input_file, internal_size_sha_file_byname
 from bzrlib.inventory import Inventory, ROOT_ID, entry_factory
-from bzrlib.lock import LogicalLockResult
 from bzrlib.mutabletree import needs_tree_write_lock
 from bzrlib.osutils import (
     file_kind,
@@ -570,7 +569,8 @@
     def lock_read(self):
         """See Branch.lock_read, and WorkingTree.unlock.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         self.branch.lock_read()
         try:
@@ -590,7 +590,7 @@
         except:
             self.branch.unlock()
             raise
-        return LogicalLockResult(self.unlock)
+        return self
 
     def _lock_self_write(self):
         """This should be called after the branch is locked."""
@@ -611,12 +611,13 @@
         except:
             self.branch.unlock()
             raise
-        return LogicalLockResult(self.unlock)
+        return self
 
     def lock_tree_write(self):
         """See MutableTree.lock_tree_write, and WorkingTree.unlock.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         self.branch.lock_read()
         return self._lock_self_write()
@@ -624,7 +625,8 @@
     def lock_write(self):
         """See MutableTree.lock_write, and WorkingTree.unlock.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         self.branch.lock_write()
         return self._lock_self_write()
@@ -1894,7 +1896,8 @@
     def lock_read(self):
         """Lock the tree for a set of operations.
 
-        :return: A bzrlib.lock.LogicalLockResult.
+        :return: An object with an unlock method which will release the lock
+            obtained.
         """
         if not self._locked:
             self._repository.lock_read()
@@ -1902,7 +1905,7 @@
                 self._dirstate.lock_read()
                 self._dirstate_locked = True
         self._locked += 1
-        return LogicalLockResult(self.unlock)
+        return self
 
     def _must_be_locked(self):
         if not self._locked:

